summaryrefslogtreecommitdiff
path: root/src/lib/player.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-07-22 21:29:40 +0100
committerCarl Hetherington <cth@carlh.net>2018-07-22 21:29:40 +0100
commitdffc146e5387a0b3f7a671d845d6c3051b0e7067 (patch)
treed92d003263699c7039fa685e5c09b5e3b3655f64 /src/lib/player.cc
parentdea824f6ff41384a5e17e23de5434cf84eccff29 (diff)
On reflection showing CCAPs over the main picture doesn't make much sense.
Diffstat (limited to 'src/lib/player.cc')
-rw-r--r--src/lib/player.cc13
1 files changed, 5 insertions, 8 deletions
diff --git a/src/lib/player.cc b/src/lib/player.cc
index 580c3e6d4..dfd309774 100644
--- a/src/lib/player.cc
+++ b/src/lib/player.cc
@@ -444,14 +444,11 @@ Player::set_ignore_caption ()
_ignore_caption = true;
}
/** Set a type of caption that this player should always burn into the image,
* regardless of the content settings.
* @param type type of captions to burn.
*/
void
-Player::set_always_burn_captions (CaptionType type)
+Player::set_always_burn_open_captions ()
{
- _always_burn_captions = type;
+ _always_burn_open_captions = true;
}
/** Sets up the player to be faster, possibly at the expense of quality */
@@ -687,7 +684,7 @@ Player::captions_for_frame (DCPTime time) const
int const vfr = _film->video_frame_rate();
for (int i = 0; i < CAPTION_COUNT; ++i) {
- bool const always = _always_burn_captions && *_always_burn_captions == i;
+ bool const always = i == CAPTION_OPEN && _always_burn_open_captions;
BOOST_FOREACH (
PlayerCaption j,
_active_captions[i].get_burnt(DCPTimePeriod(time, time + DCPTime::from_frames(1, vfr)), always)
@@ -960,7 +957,7 @@ Player::subtitle_stop (weak_ptr<Piece> wp, weak_ptr<const CaptionContent> wc, Co
pair<PlayerCaption, DCPTime> from = _active_captions[type].add_to (wc, dcp_to);
- bool const always = _always_burn_captions && *_always_burn_captions == type;
+ bool const always = type == CAPTION_OPEN && _always_burn_open_captions;
if (caption->use() && !always && !caption->burn()) {
Caption (from.first, type, DCPTimePeriod (from.second, dcp_to));
}
@@ -444,14 +444,11 @@ Player::set_ignore_caption ()
_ignore_caption = true;
}
-/** Set a type of caption that this player should always burn into the image,
- * regardless of the content settings.
- * @param type type of captions to burn.
- */
+/** Set the player to always burn open captions into the image regardless of the content settings */
void